-------------------------------------------------------------------------------
-- MrTrader 
--
-- Suite of tools for the avid crafter.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

function MRTSkillWindow_OnSkillClick(self, button)
	if ( IsShiftKeyDown() ) then
		HandleModifiedItemClick(GetTradeSkillRecipeLink(self:GetID()));
	else
		MRTSkillWindow:SelectSkill(self, button);
	end
end

function MRTSkillWindow_OnFilterClick(self, button)
	if(button == "LeftButton") then
		MRTSkillWindow:SelectFilter(self.filterRef);
	elseif(button == "RightButton") then
		MRTSkillContext:DisplayFilterContext(self);
	end
end

function MRTSkillWindow_OnShow()
	-- Empty
end

function MRTSkillWindow_OnHide()
	CloseTradeSkill();
	MRTNewCategoryFrame:Hide();
end

function MRTSkillWindow_OnMouseDown()
	if( MRTSkillFrame:IsMovable() ) then
		MRTSkillFrame:StartMoving();
	end
end

function MRTSkillWindow_OnMouseUp()
	if( MRTSkillFrame:IsMovable() ) then
		MRTSkillFrame:StopMovingOrSizing();
		MrTrader:StoreLocation("MRTSkillFrame", MRTSkillFrame);
	end
end

function MRTSkillWindow_OnDecrementClick()
	if ( MRTSkillInputBox:GetNumber() > 0 ) then
		MRTSkillInputBox:SetNumber(MRTSkillInputBox:GetNumber() - 1);
	end
end

function MRTSkillWindow_OnIncrementClick()
	if ( MRTSkillInputBox:GetNumber() < 100 ) then
		MRTSkillInputBox:SetNumber(MRTSkillInputBox:GetNumber() + 1);
	end
end

function MRTSkillWindow_OnQueueToggle(checkbutton, button)
	if( checkbutton:GetChecked() ) then
		MRTQueueWindow:Show();
	else
		MRTQueueWindow:Close();
	end
end

function MRTSkillWindow_OnEnterSkillIcon(item)
	if(item:GetID() == nil) then
		return;
	end
	
	GameTooltip:SetOwner(MRTSkillFrame);

	if ( strmatch(item:GetName(), "MRTSkillButton(%d+)Reagent") ) then
		GameTooltip:SetTradeSkillItem(item:GetParent():GetID(), item:GetID());
	elseif ( strmatch(item:GetName(), "MRTSkillButton(%d+)Icon") ) then
		GameTooltip:SetTradeSkillItem(item:GetParent():GetID());
	elseif ( strmatch(item:GetName(), "MRTSkillButton(%d+)") ) then
		if( MrTrader:ShouldDisplaySkillListTooltip() ) then
			-- GameTooltip:SetHyperlink(GetTradeSkillRecipeLink(item:GetID()));
			local skillName = GetTradeSkillInfo(item:GetID());
			local skillLink = GetTradeSkillItemLink(item:GetID());
			
			if( skillName and skillLink ) then
				local _, _, quality, ilvl, reqLevel = GetItemInfo(GetTradeSkillItemLink(item:GetID()));
				local numReagents = GetTradeSkillNumReagents(item:GetID());
			
				GameTooltip:ClearLines();
				GameTooltip:AddLine(skillName, GetItemQualityColor(quality or 1));
				GameTooltip:AddLine(GetTradeSkillDescription(item:GetID()), 1.0, 1.0, 1.0, 1);
				GameTooltip:AddLine("    ");
				GameTooltip:AddLine("Reagents:", 1.0, 1.0, 1.0);
			
				for j=1, numReagents, 1 do
					local reagentName, reagentTexture, reagentCount, playerReagentCount = GetTradeSkillReagentInfo(item:GetID(), j); 
					local reagentItemLink = GetTradeSkillReagentItemLink(item:GetID(), j);
					if(reagentName and reagentItemLink) then
						local _, _, reagentQuality = GetItemInfo(reagentItemLink);
						local r, g, b = GetItemQualityColor(reagentQuality or 0);
						local hasEnough = 0.0;
				
						if (playerReagentCount >= reagentCount) then
							hasEnough = 1.0;
						end
			    		GameTooltip:AddDoubleLine(reagentName, playerReagentCount.."/"..reagentCount, r, g, b, 1.0, 1.0 * hasEnough, 1.0 * hasEnough);				
						GameTooltip:AddTexture(reagentTexture);
					else
						GameTooltip:AddLine("Retrieving", 1.0, 0.0, 0.0, 0.0);
					end
				end
			
				GameTooltip:Show();
			end
		end
	end
	
	GameTooltip:ClearAllPoints();
	local rightOffset = MRTSkillFrame:GetRight();
	local tooltipWidth = GameTooltip:GetWidth();
	local screenRight = UIParent:GetWidth();
		
	if(rightOffset + tooltipWidth > screenRight) then
		GameTooltip:SetPoint("TOPRIGHT", MRTSkillFrame, "TOPLEFT", 0, -10);		
	else
		GameTooltip:SetPoint("TOPLEFT", MRTSkillFrame, "TOPRIGHT", 0, -10);
	end
	
	CursorUpdate(item);
end

function MRTSkillWindow_OnSearchTextChange(field)
	local text = field:GetText();
	
	if ( text == SEARCH ) then
		SetTradeSkillItemNameFilter("");
		return;
	end

	local minLevel, maxLevel;
	local approxLevel = strmatch(text, "^~(%d+)");
	if ( approxLevel ) then
		minLevel = approxLevel - 2;
		maxLevel = approxLevel + 2;
	else
		minLevel, maxLevel = strmatch(text, "^(%d+)%s*-*%s*(%d*)$");
	end
	if ( minLevel ) then
		if ( maxLevel == "" or maxLevel < minLevel ) then
			maxLevel = minLevel;
		end
		SetTradeSkillItemNameFilter(nil);
		SetTradeSkillItemLevelFilter(minLevel, maxLevel);
	else
		SetTradeSkillItemLevelFilter(0, 0);
		SetTradeSkillItemNameFilter(text);
	end	
	
	MRTSkillWindow_Update();
end

function MRTSkillWindow_Update()
	MRTSkillWindow:UpdateSkillList();
end

function MRTSkillWindow_UpdateFilters()
	--MRTSkillWindow:UpdateFilters();
	MRTSkillWindow:DrawFilters();
end

function MRTSkillWindow_UpdateHeaders()
	MRTSkillWindow:DrawHeader();
end

-----
-- New Category Dialog
-----
function MRTNewCategoryFrame_Cancel()
	MRTNewCategoryFrame:Hide();
end

function MRTNewCategoryFrame_Okay()
	local categoryName = MRTNewCategoryFrameCategoryName:GetText();

	if( categoryName == "" or categoryName == nil ) then
		return;
	end

	local tradeskillSpellID = MrTrader:MatchPartialCraftSkillName(GetTradeSkillLine());
	local favorites = MrTrader:GetFavoritesForSkill(tradeskillSpellID);
	
	if( favorites ~= nil and favorites[categoryName] == nil ) then
		MrTrader:AddFavoriteCategoryToSkill(tradeskillSpellID, categoryName);

		if( MRTNewCategoryFrame.referenceSkill ) then
			-- Set the reference skill up in the new category			
			local skillSpellID = MrTrader:GetSpellIDForRecipe(GetTradeSkillRecipeLink(MRTNewCategoryFrame.referenceSkill));
			MrTrader:AddFavoriteToSkill(tradeskillSpellID, categoryName, skillSpellID);
		end
	end
	
	MRTSkillWindow:PopulateFilterTree();
	MRTSkillWindow:Update();
	MRTNewCategoryFrame:Hide();
end